@@ -1,7 +1,6 @@
+// License: GPL. For details, see Readme.txt file.
 package org.openstreetmap.gui.jmapviewer.events;
 
-//License: GPL.
-
 import java.util.EventObject;
 
 /**
@@ -12,7 +11,7 @@ import java.util.EventObject;
  *
  */
 public class JMVCommandEvent extends EventObject {
-    public static enum COMMAND {
+    public enum COMMAND {
         MOVE,
         ZOOM
     }
