@@ -1,7 +1,6 @@
+// License: GPL. For details, see Readme.txt file.
 package org.openstreetmap.gui.jmapviewer.interfaces;
 
-//License: GPL. Copyright 2012 by Dirk Stöcker
-
 import org.openstreetmap.gui.jmapviewer.Tile;
 
 /**
@@ -17,5 +16,16 @@ public interface TileJob extends Runnable {
      *
      * @return {@link Tile} to be handled
      */
-    public Tile getTile();
+    Tile getTile();
+
+    /**
+     * submits download job to backend.
+     */
+    void submit();
+
+    /**
+     * submits download job to backend.
+     * @param force true if the load should skip all the caches (local &amp; remote)
+     */
+    void submit(boolean force);
 }
